#
# spec file for package ktls-utils
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

Name:           ktls-utils
Version:        0.9+4.g01b3018
Release:        1.2
Summary:        Agent for performing handshakes for kernel TLS sockets
License:        GPL-2.0-only
Group:          System/Kernel
URL:            https://github.com/oracle/ktls-utils
Source:         ktls-utils-%{version}.tar
BuildRequires:  autoconf
BuildRequires:  libtool
BuildRequires:  pkgconfig(gnutls) >= 3.3.0
BuildRequires:  pkgconfig(libkeyutils)
BuildRequires:  pkgconfig(glib-2.0) >= 2.6
BuildRequires:  pkgconfig(libnl-3.0) >= 3.1
BuildRequires:  pkgconfig(systemd)

%description
In-kernel TLS consumers need a mechanism to perform TLS handshakes on a
connected socket to negotiate TLS session parameters that can then be
programmed into the kernel's TLS record protocol engine.

This package of software provides a TLS handshake user agent that listens for
kernel requests and then materializes a user space socket endpoint on which to
perform these handshakes. The resulting negotiated session parameters are
passed back to the kernel via standard kTLS socket options.

%prep
%setup -q -n ktls-utils-%{version}

%build
./autogen.sh
%{configure} --with-systemd
%{make_build} CFLAGS="%{optflags}"

%install
%{make_install}

%pre
%service_add_pre tlshd.service

%post
%service_add_post tlshd.service

%preun
%service_del_preun tlshd.service

%postun
%service_del_postun tlshd.service

%files
%doc README.md
%license LICENSE.txt
%{_sbindir}/tlshd
%{_unitdir}/tlshd.service
%config(noreplace) %{_sysconfdir}/tlshd.conf
%{_mandir}/man8/tlshd.8*
%{_mandir}/man5/tlshd.conf.5*

%changelog
* Wed Jan 17 2024 Martin Wilck <mwilck@suse.com>
- Spec file:
  * fix summary and license
  * use pkgconfig for BuildRequires
  * remove superfluous PreReq dependencies
  * use %%config(noreplace) for the config file (because it may
    contain paths to key files)
  * remove BuildRoot
  * simplify build section
* Tue Jan  9 2024 Martin Wilck <mwilck@suse.com>
- Update to version 0.9+4.g01b3018 (jsc#PED-7559)
  * _service: move to openSUSE git repository
- Patches now in git, remove them from spec file:
  * del 0001-netlink-de-constify-nla_policy
  * del 0001-tlshd-Allow-for-compilation-with-older-libnl-librari.patch
  * del 0002-tlshd-Check-for-gnutls_get_system_config_file.patch
  * del 0003-tlshd-add-delay-configuration-parameter.patch
  Wed 16 Aug 2023 08:21:59 PM CEST - Hannes Reinecke <hare@suse.de>
- Reshuffle patches to match upstream submission:
  * Remove 0001-netlink-de-constify-nla_policy
  * Add 0001-tlshd-Allow-for-compilation-with-older-libnl-librari.patch
  * Remove 0001-Check-for-gnutls_get_system_config_file.patch
  * Add 0002-tlshd-Check-for-gnutls_get_system_config_file.patch
  * Remove 0001-Add-tlshd_delay-configuration-option.patch
  * Add 0003-tlshd-add-delay-configuration-parameter.patch
  Wed 16 Aug 2023 07:55:46 AM CEST - Hannes Reinecke <hare@suse.de>
- Add patch to exercise handshake timeout
  * 0001-Add-tlshd_delay-configuration-option.patch
- Add patch to allow compilation on older releases
  * 0001-Check-for-gnutls_get_system_config_file.patch
  Sat 01 Jul 2023 10:40:46 AM CEST - Hannes Reinecke <hare@suse.de>
- Add patch for older libnl versions
  + 0001-netlink-de-constify-nla_policy.patch
- Fix build error on 32-bit
  + 0001-tlshd-fix-max-config-file-size-comparison.patch
  Fri 30 Jun 2023 12:58:27 PM CEST - Hannes Reinecke <hare@suse.de>
- Initial package, version 0.9
